<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>ReadmeDialog</name>
    <message>
        <location filename="../ShowReadmeDialog.ui" line="+14"/>
        <source>Readme</source>
        <translation>Čtěte</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Don&apos;t show this dialog at startup</source>
        <translation>Nezobrazoval tento dialog při startu</translation>
    </message>
</context>
<context>
    <name>ShowReadme</name>
    <message>
        <location filename="../ShowReadme.js" line="+46"/>
        <source>File &apos;%1&apos; doesn&apos;t exist.</source>
        <translation>Soubor &quot;%1&apos; neexistuje.</translation>
    </message>
    <message>
        <location filename="../ShowReadmeInit.js" line="+2"/>
        <source>Show &amp;Readme</source>
        <translation>Zobrazit &amp;Čti mne</translation>
    </message>
</context>
</TS>
